@@ -2,8 +2,7 @@ import fnmatch
 import stat
 from logging import getLogger
 from os import listdir
-from os.path import dirname, isdir, isfile, join, basename
-from shutil import copyfileobj
+from os.path import dirname, isdir, isfile, join, basename, getsize
 
 from os_utils.path import delete, mkpath
 from paramiko import AutoAddPolicy, SSHClient
@@ -92,17 +91,23 @@ class SFTPClient(FTPClientBase):
         if dst.endswith('/') or isdir(dst):
             dst = join(dst, basename(src))
         delete(dst)
-        with self.ftp.open(src, 'rb') as remote_file:
-            copyfileobj(remote_file, open(dst, 'wb'))
+        self.ftp.get(src, dst)
+        src_size = self.file_size(src)
+        dst_size = getsize(dst)
+        if src_size != dst_size:
+            raise SFTPClientError('source and destination size mismatch after copy, '
+                                  'src: {} vs dst: {}'.format(src_size, dst_size))
 
     def upload_file(self, src, dst):
         self.ftp.put(src, dst)
 
-    def file_size(self, path, bytes_magnitude=1):
+    def file_size(self, path, bytes_magnitude=0):
         """
-        :param bytes_magnitude: 1-bytes, 2-Kb, 3-Mb, 4-Gb
+        :param bytes_magnitude: 0-bytes, 1-Kb, 2-Mb, 3-Gb
         """
         stat = self.ftp.stat(path)
+        if bytes_magnitude == 0:
+            return stat.st_size
         return stat.st_size / 1024**bytes_magnitude
 
     def exists(self, path):
